@@ -1,11 +1,15 @@
 import click
+from colorama import Fore, Style, init
 
 from .main import create_project_structure
 
-version = '1.4'
+version = '2.8'
 
-# ASCII art for LDJANGO
-LDJANGO_ASCII = """
+# Initialize colorama
+init(autoreset=True)
+
+# ASCII art for LDJANGO with colors
+LDJANGO_ASCII = f"""{Fore.CYAN}
 
    __     _  _                         
   / /  __| |(_) __ _ _ __   __ _  ___  
@@ -14,10 +18,10 @@ LDJANGO_ASCII = """
 \____/\__,_|/ |\__,_|_| |_|\__, |\___/ 
           |__/             |___/       
 
-"""
+{Style.RESET_ALL}"""
 
 @click.group()
-@click.version_option(version=version, message=f'{LDJANGO_ASCII}\nldjango version {version}')
+@click.version_option(version=version, message=f'{LDJANGO_ASCII}\n{Fore.GREEN}ldjango version {version}{Style.RESET_ALL}')
 @click.help_option('-h', '--help')
 def cli():
     """ldjango: CLI tool for creating Django projects with a predefined structure."""
@@ -26,16 +30,17 @@ def cli():
 
 @cli.command()
 def makeproject():
-    click.echo("ldjango: CLI tool for creating Django projects with a predefined structure.")
+    click.echo(f"{Fore.YELLOW}Welcome to ldjango: Your Django project creator!{Style.RESET_ALL}")
     """Create a new Django project with a predefined structure."""
-    project_name = click.prompt("What is your project name?")
-    app_count = click.prompt("How many applications do you want to create?", type=int)
+    project_name = click.prompt(f"{Fore.CYAN}Enter your project name{Style.RESET_ALL}")
+    app_count = click.prompt(f"{Fore.CYAN}How many applications do you want to create?{Style.RESET_ALL}", type=int)
     
     app_names = []
     for i in range(app_count):
-        app_name = click.prompt(f"Django Application Name {i + 1}")
+        app_name = click.prompt(f"{Fore.MAGENTA}Django Application Name {i + 1}{Style.RESET_ALL}")
         app_names.append(app_name)
     
+    click.echo(f"\n{Fore.GREEN}Creating your Django project...{Style.RESET_ALL}")
     create_project_structure(project_name, app_names)
 
 if __name__ == '__main__':
